"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateRCFile = void 0;
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const semver_1 = __importDefault(require("semver"));
async function generateRCFile(resourcePath, executableFilename, data = {}) {
    const S = JSON.stringify;
    let result = '#include "winresrc.h"\n';
    if (data.icon) {
        await fs_1.promises.copyFile(data.icon, path_1.default.join(resourcePath, 'boxednode.ico'));
        result += '1 ICON boxednode.ico\n';
    }
    const version = semver_1.default.parse(data.version || '0.0.0');
    result += `

// Version resource
VS_VERSION_INFO VERSIONINFO
 FILEVERSION ${version.major},${version.minor},${version.patch},0
 PRODUCTVERSION ${version.major},${version.minor},${version.patch},0
 FILEFLAGSMASK 0x3fL
#ifdef _DEBUG
 FILEFLAGS VS_FF_DEBUG
#else
#  ifdef NODE_VERSION_IS_RELEASE
    FILEFLAGS 0x0L
#  else
    FILEFLAGS VS_FF_PRERELEASE
#  endif
#endif

 FILEOS VOS_NT_WINDOWS32
 FILETYPE VFT_APP
 FILESUBTYPE 0x0L
BEGIN
    BLOCK "StringFileInfo"
    BEGIN
        BLOCK "040904b0"
        BEGIN
            VALUE "FileVersion", ${S(version.version)}
            VALUE "ProductVersion", ${S(version.version)}`;
    if (data.manufacturer) {
        result += `
            VALUE "CompanyName", ${S(data.manufacturer)}`;
    }
    if (data.name) {
        result += `
            VALUE "InternalName", ${S(data.name)}
            VALUE "ProductName", ${S(data.name)}`;
    }
    if (data.copyright) {
        result += `
            VALUE "LegalCopyright", ${S(data.copyright)}`;
    }
    if (data.description) {
        result += `
            VALUE "FileDescription", ${S(data.description)}`;
    }
    result += `
            VALUE "OriginalFilename", ${S(path_1.default.basename(executableFilename))}
        END
    END
    BLOCK "VarFileInfo"
    BEGIN
        VALUE "Translation", 0x409, 1200
    END
END
`;
    return result;
}
exports.generateRCFile = generateRCFile;
//# sourceMappingURL=executable-metadata.js.map