"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.npm = exports.objhash = exports.copyRecursive = exports.spawnBuildCommand = exports.pipeline = void 0;
const fs_1 = require("fs");
const crypto_1 = __importDefault(require("crypto"));
const child_process_1 = __importDefault(require("child_process"));
const util_1 = require("util");
const tar_1 = __importDefault(require("tar"));
const stream_1 = __importDefault(require("stream"));
const events_1 = require("events");
exports.pipeline = (0, util_1.promisify)(stream_1.default.pipeline);
async function spawnBuildCommand(command, options) {
    var _a, _b;
    options.logger.stepStarting(`Running ${command.join(' ')}`);
    const env = options.env;
    if (process.platform === 'win32') {
        const PATH = (_b = (_a = env.PATH) !== null && _a !== void 0 ? _a : env.Path) !== null && _b !== void 0 ? _b : env.path;
        delete env.PATH;
        delete env.Path;
        delete env.path;
        env.PATH = PATH;
    }
    const proc = child_process_1.default.spawn(command[0], command.slice(1), {
        stdio: 'inherit',
        ...options,
        env
    });
    const [code] = await (0, events_1.once)(proc, 'exit');
    if (code !== 0) {
        throw new Error(`Command failed: ${command.join(' ')} (code ${code})`);
    }
    options.logger.stepCompleted();
}
exports.spawnBuildCommand = spawnBuildCommand;
async function copyRecursive(sourceDir, targetDir) {
    await fs_1.promises.mkdir(targetDir, { recursive: true });
    await (0, exports.pipeline)(tar_1.default.c({
        cwd: sourceDir,
        gzip: false
    }, ['./']), tar_1.default.x({
        cwd: targetDir
    }));
}
exports.copyRecursive = copyRecursive;
function objhash(value) {
    return crypto_1.default.createHash('sha256')
        .update(JSON.stringify(value))
        .digest('hex')
        .slice(0, 32);
}
exports.objhash = objhash;
function npm() {
    if (process.env.npm_execpath) {
        return [process.execPath, process.env.npm_execpath];
    }
    else {
        return ['npm'];
    }
}
exports.npm = npm;
//# sourceMappingURL=helpers.js.map