"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoggerImpl = void 0;
const chalk_1 = __importDefault(require("chalk"));
const cli_progress_1 = __importDefault(require("cli-progress"));
class LoggerImpl {
    constructor() {
        this.currentStep = '';
        this.cliProgress = null;
    }
    stepStarting(info) {
        if (this.currentStep) {
            this.stepCompleted();
        }
        this.currentStep = info;
        console.warn(`${chalk_1.default.yellow('→')}  ${info} ...`);
    }
    _stepDone() {
        this.currentStep = '';
        if (this.cliProgress) {
            this.cliProgress.stop();
            this.cliProgress = null;
        }
    }
    stepCompleted() {
        const doneText = this.currentStep;
        this._stepDone();
        console.warn(chalk_1.default.green(`  ✓  Completed: ${doneText}`));
    }
    stepFailed(err) {
        this._stepDone();
        console.warn(chalk_1.default.red(`  ✖  Failed: ${err.message}`));
    }
    startProgress(maximum) {
        this.cliProgress = new cli_progress_1.default.SingleBar({}, cli_progress_1.default.Presets.shades_classic);
        this.cliProgress.start(maximum, 0);
    }
    doProgress(current) {
        this.cliProgress.update(current);
    }
}
exports.LoggerImpl = LoggerImpl;
//# sourceMappingURL=logger.js.map